@@ -368,13 +368,14 @@ gnc_search_dialog_display_results (GNCSearchWindow *sw)
     if (gnc_query_view_get_num_entries(GNC_QUERY_VIEW(sw->result_view)) < max_count)
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (sw->new_rb), TRUE);
 
-    /* If there is only one item then select it */
-    if (gnc_query_view_get_num_entries (GNC_QUERY_VIEW(sw->result_view)) == 1)
+    /* If there are results then select the first, and grab focus */
+    if (gnc_query_view_get_num_entries (GNC_QUERY_VIEW(sw->result_view)) > 0)
     {
         GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(sw->result_view));
         GtkTreePath *path = gtk_tree_path_new_first ();
         gtk_tree_selection_select_path (selection, path);
         gtk_tree_path_free (path);
+        gtk_widget_grab_focus (sw->result_view);
     }
 }
 
@@ -656,7 +657,7 @@ search_cancel_cb (GtkButton *button, GNCSearchWindow *sw)
 static void
 search_help_cb (GtkButton *button, GNCSearchWindow *sw)
 {
-    gnc_gnome_help (GTK_WINDOW(sw->dialog), HF_HELP, HL_FIND_TRANSACTIONS);
+    gnc_gnome_help (GTK_WINDOW(sw->dialog), DF_MANUAL, DL_FIND_TRANSACTIONS);
 }
 
 static void
@@ -1116,7 +1117,7 @@ type_label_to_new_button(const gchar* type_label)
     else
     {
         PWARN("No translatable new-button label found for search type \"%s\", please add one into dialog-search.c!", type_label);
-        return C_("Item represents an unknown object type (in the sense of bill, customer, invoice, transaction, split,...)!", "New item");
+        return C_("Item represents an unknown object type (in the sense of bill, customer, invoice, transaction, split,…)!", "New item");
     }
 }
 
