@@ -26,6 +26,10 @@
 
 #include "Account.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* Note: make sure to update the help text for this in prefs.scm if these
  * change!  These macros define the account types for which an auto interest
  * xfer dialog could pop up, if the user's preferences allow it.
@@ -138,7 +142,7 @@ Account * gnc_ui_new_accounts_from_name_window (GtkWindow *parent,
 /* Note that the caller owns the valid_types list */
 Account * gnc_ui_new_accounts_from_name_window_with_types (GtkWindow *parent,
                                                            const char *name,
-        GList *valid_types);
+                                                           GList *valid_types);
 
 
 /** Display a modal window for creating a new account.  This function
@@ -162,10 +166,10 @@ Account * gnc_ui_new_accounts_from_name_window_with_types (GtkWindow *parent,
  *  @return A pointer to the newly created account.
  */
 Account * gnc_ui_new_accounts_from_name_with_defaults (GtkWindow *parent,
-                                        const char *name,
-                                        GList *valid_types,
-                                        const gnc_commodity * default_commodity,
-                                        Account * parent_acct);
+                                                       const char *name,
+                                                       GList *valid_types,
+                                                       const gnc_commodity *default_commodity,
+                                                       Account *parent_acct);
 
 /*
  * register a callback that gets called when the account has changed
@@ -180,6 +184,10 @@ void gnc_account_renumber_create_dialog (GtkWidget *window, Account *account);
 
 void gnc_account_cascade_properties_dialog (GtkWidget *window, Account *account);
 
+#ifdef __cplusplus
+}
+#endif
+
 /** @} */
 /** @} */
 
