@@ -53,8 +53,6 @@ enum
 
 static guint amount_edit_signals [LAST_SIGNAL] = { 0 };
 
-static void gnc_amount_edit_init (GNCAmountEdit *gae);
-static void gnc_amount_edit_class_init (GNCAmountEditClass *klass);
 static void gnc_amount_edit_changed (GtkEditable *gae,
                                      gpointer user_data);
 static void gnc_amount_edit_paste_clipboard (GtkEntry *entry,
