@@ -26,7 +26,7 @@
 
 /** @addtogroup MenuPlugins
     @{ */
-/** @addtogroup PluginMenuAdditions Non-GtkAction Menu Support
+/** @addtogroup PluginMenuAdditions Non-GAction Menu Support
     @{ */
 /** @file gnc-plugin-menu-additions.c
     @brief Functions providing menu items from scheme code.
@@ -45,15 +45,13 @@
 #include "gnc-window.h"
 #include "gnc-ui.h"
 #include "gnc-menu-extensions.h"
+#include "gnc-gtk-utils.h"
 
-static GObjectClass *parent_class = NULL;
-
-static void gnc_plugin_menu_additions_class_init (GncPluginMenuAdditionsClass *klass);
-static void gnc_plugin_menu_additions_init (GncPluginMenuAdditions *plugin);
 static void gnc_plugin_menu_additions_finalize (GObject *object);
 
 static void gnc_plugin_menu_additions_add_to_window (GncPlugin *plugin, GncMainWindow *window, GQuark type);
 static void gnc_plugin_menu_additions_remove_from_window (GncPlugin *plugin, GncMainWindow *window, GQuark type);
+static void gnc_plugin_menu_additions_action_new_cb (GSimpleAction *simple, GVariant *parameter, gpointer user_data);
 
 /* Command callbacks */
 
@@ -62,15 +60,12 @@ static QofLogModule log_module = GNC_MOD_GUI;
 
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-menu-additions-actions"
 
-/** Private data for this plugin.  This data structure is unused. */
-typedef struct GncPluginMenuAdditionsPrivate
+struct _GncPluginMenuAdditions
 {
-    gpointer dummy;
-} GncPluginMenuAdditionsPrivate;
-
-#define GNC_PLUGIN_MENU_ADDITIONS_GET_PRIVATE(o)  \
-   ((GncPluginMenuAdditionsPrivate*)gnc_plugin_menu_additions_get_instance_private((GncPluginMenuAdditions*)o))
+    GncPlugin gnc_plugin;
 
+    GHashTable *item_hash;
+};
 
 /** Per-window private data for this plugin.  This plugin is unique in
  *  that it manages its own menu items. */
@@ -79,17 +74,26 @@ typedef struct _GncPluginMenuAdditionsPerWindow
     /** The menu/toolbar action information associated with a specific
         window.  This plugin must maintain its own data because of the
         way the menus are currently built. */
-    GncMainWindow  *window;
-    GtkUIManager   *ui_manager;
-    GtkActionGroup *group;
-    gint merge_id;
+    GHashTable     *item_hash;
+    GHashTable     *build_menu_hash;
+    GMenu          *report_menu;
+    GMenu          *sub_menu;
 } GncPluginMenuAdditionsPerWindow;
 
+/** An array of all of the actions provided by the account tree
+ *  plugin. */
+static GActionEntry gnc_plugin_actions [] =
+{
+    { "AdditionsAction", gnc_plugin_menu_additions_action_new_cb, "s", NULL, NULL },
+};
+/** The number of actions provided by this plugin. */
+static guint gnc_plugin_n_actions = G_N_ELEMENTS(gnc_plugin_actions);
+
 /************************************************************
  *                  Object Implementation                   *
  ************************************************************/
 
-G_DEFINE_TYPE_WITH_PRIVATE(GncPluginMenuAdditions, gnc_plugin_menu_additions, GNC_TYPE_PLUGIN)
+G_DEFINE_TYPE(GncPluginMenuAdditions, gnc_plugin_menu_additions, GNC_TYPE_PLUGIN)
 
 static void
 gnc_plugin_menu_additions_class_init (GncPluginMenuAdditionsClass *klass)
@@ -97,16 +101,17 @@ gnc_plugin_menu_additions_class_init (GncPluginMenuAdditionsClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GncPluginClass *plugin_class = GNC_PLUGIN_CLASS (klass);
 
-    parent_class = g_type_class_peek_parent (klass);
-
     object_class->finalize = gnc_plugin_menu_additions_finalize;
 
     /* plugin info */
     plugin_class->plugin_name   = GNC_PLUGIN_MENU_ADDITIONS_NAME;
 
     /* function overrides */
-    plugin_class->add_to_window = gnc_plugin_menu_additions_add_to_window;
+    plugin_class->add_to_window      = gnc_plugin_menu_additions_add_to_window;
     plugin_class->remove_from_window = gnc_plugin_menu_additions_remove_from_window;
+    plugin_class->actions_name       = PLUGIN_ACTIONS_NAME;
+    plugin_class->actions            = gnc_plugin_actions;
+    plugin_class->n_actions          = gnc_plugin_n_actions;
 }
 
 static void
@@ -119,10 +124,13 @@ gnc_plugin_menu_additions_init (GncPluginMenuAdditions *plugin)
 static void
 gnc_plugin_menu_additions_finalize (GObject *object)
 {
-    g_return_if_fail (GNC_IS_PLUGIN_MENU_ADDITIONS (object));
+    g_return_if_fail (GNC_IS_PLUGIN_MENU_ADDITIONS(object));
 
     ENTER("plugin %p", object);
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+
+    g_hash_table_destroy (GNC_PLUGIN_MENU_ADDITIONS(object)->item_hash);
+
+    G_OBJECT_CLASS (gnc_plugin_menu_additions_parent_class)->finalize (object);
     LEAVE("");
 }
 
@@ -161,27 +169,33 @@ gnc_main_window_to_scm (GncMainWindow *window)
     return SWIG_NewPointerObj(window, main_window_type, 0);
 }
 
-
-/** The user has selected one of the items added by this plugin.
- *  Invoke the callback function that was registered along with the
- *  menu item.
- *
- *  @param action A pointer to the action selected by the user.  This
- *  action represents one of the items in the file history menu.
- *
- *  @param data A pointer to the gnc-main-window data to be used by
- *  this function.  This is mainly to find out which window it was
- *  that had a menu selected.
- */
 static void
-gnc_plugin_menu_additions_action_cb (GtkAction *action,
-                                     GncMainWindowActionData *data)
+gnc_plugin_menu_additions_action_new_cb (GSimpleAction *simple,
+                                         GVariant      *parameter,
+                                         gpointer       user_data)
 {
+    SCM extension;
+    gsize length;
+    const gchar *action_name;
 
-    g_return_if_fail(GTK_IS_ACTION(action));
-    g_return_if_fail(data != NULL);
+    g_return_if_fail (G_IS_SIMPLE_ACTION(simple));
 
-    gnc_extension_invoke_cb(data->data, gnc_main_window_to_scm(data->window));
+    ENTER("");
+
+    action_name = g_variant_get_string (parameter, &length);
+
+    PINFO("action name is '%s'", action_name);
+
+    GncMainWindowActionData *cb_data = user_data;
+    GncPluginMenuAdditions *plugin = GNC_PLUGIN_MENU_ADDITIONS(cb_data->data);
+    extension = g_hash_table_lookup (plugin->item_hash, action_name);
+
+    if (extension)
+    {
+        PINFO("Found action in table");
+        gnc_extension_invoke_cb (extension, gnc_main_window_to_scm (cb_data->window));
+    }
+    LEAVE("");
 }
 
 
@@ -201,9 +215,9 @@ gnc_menu_additions_sort (ExtensionInfo *a, ExtensionInfo *b)
 {
     if (a->type == b->type)
         return strcmp(a->sort_key, b->sort_key);
-    else if (a->type == GTK_UI_MANAGER_MENU)
+    else if (a->type == GNC_SUB_MENU_ITEM)
         return -1;
-    else if (b->type == GTK_UI_MANAGER_MENU)
+    else if (b->type == GNC_SUB_MENU_ITEM)
         return 1;
     else
         return 0;
@@ -238,23 +252,23 @@ gnc_menu_additions_do_preassigned_accel (ExtensionInfo *info, GHashTable *table)
     gchar *map, *new_map, *accel_key;
     const gchar *ptr;
 
-    ENTER("Checking %s/%s [%s]", info->path, info->ae.label, info->ae.name);
+    ENTER("Checking %s/%s [%s]", info->path, info->action_label, info->action_name);
     if (info->accel_assigned)
     {
         LEAVE("Already processed");
         return;
     }
 
-    if (!g_utf8_validate(info->ae.label, -1, NULL))
+    if (!g_utf8_validate(info->action_label, -1, NULL))
     {
-        g_warning("Extension menu label '%s' is not valid utf8.", info->ae.label);
+        g_warning ("Extension menu label '%s' is not valid utf8.", info->action_label);
         info->accel_assigned = TRUE;
         LEAVE("Label is invalid utf8");
         return;
     }
 
     /* Was an accelerator pre-assigned in the source? */
-    ptr = g_utf8_strchr(info->ae.label, -1, '_');
+    ptr = g_utf8_strchr (info->action_label, -1, '_');
     if (ptr == NULL)
     {
         LEAVE("not preassigned");
@@ -298,7 +312,7 @@ gnc_menu_additions_assign_accel (ExtensionInfo *info, GHashTable *table)
     gint len;
     gboolean map_allocated = FALSE;
 
-    ENTER("Checking %s/%s [%s]", info->path, info->ae.label, info->ae.name);
+    ENTER("Checking %s/%s [%s]", info->path, info->action_label, info->action_name);
     if (info->accel_assigned)
     {
         LEAVE("Already processed");
@@ -314,7 +328,7 @@ gnc_menu_additions_assign_accel (ExtensionInfo *info, GHashTable *table)
     }
     DEBUG("map '%s', path %s", map, info->path);
 
-    for (ptr = info->ae.label; *ptr; ptr = g_utf8_next_char(ptr))
+    for (ptr = info->action_label; *ptr; ptr = g_utf8_next_char(ptr))
     {
         uni = g_utf8_get_char(ptr);
         if (!g_unichar_isalpha(uni))
@@ -340,13 +354,13 @@ gnc_menu_additions_assign_accel (ExtensionInfo *info, GHashTable *table)
     }
 
     /* Now build a new string in the form "<start>_<end>". */
-    start = g_strndup(info->ae.label, ptr - info->ae.label);
+    start = g_strndup (info->action_label, ptr - info->action_label);
     DEBUG("start %p, len %ld, text '%s'", start, g_utf8_strlen(start, -1), start);
     new_label = g_strconcat(start, "_", ptr, (gchar *)NULL);
     g_free(start);
-    DEBUG("label '%s' -> '%s'", info->ae.label, new_label);
-    g_free((gchar *)info->ae.label);
-    info->ae.label = new_label;
+    DEBUG("label '%s' -> '%s'", info->action_label, new_label);
+    g_free((gchar *)info->action_label);
+    info->action_label = new_label;
 
     /* Now build a new map. Old one freed automatically. */
     new_map = g_strconcat(map, buf, (gchar *)NULL);
@@ -361,6 +375,29 @@ gnc_menu_additions_assign_accel (ExtensionInfo *info, GHashTable *table)
     LEAVE("assigned");
 }
 
+static GMenuItem *
+setup_gmenu_item_with_tooltip (ExtensionInfo *ext_info)
+{
+    GMenuItem *gmenu_item = NULL;
+
+    if (g_strcmp0 (ext_info->typeStr, "menuitem") == 0)
+    {
+        gmenu_item = g_menu_item_new (ext_info->action_label, NULL);
+        g_menu_item_set_action_and_target_value (gmenu_item, "gnc-plugin-menu-additions-actions.AdditionsAction",
+                                                 g_variant_new_string (ext_info->action_name));
+
+        g_menu_item_set_attribute (gmenu_item, GNC_MENU_ATTRIBUTE_TOOLTIP, "s", ext_info->action_tooltip);
+    }
+
+    if (g_strcmp0 (ext_info->typeStr, "menu") == 0)
+    {
+        GMenuModel *sub_menu = G_MENU_MODEL(g_menu_new ());
+
+        gmenu_item = g_menu_item_new_submenu (ext_info->action_label, sub_menu);
+        g_object_set_data (G_OBJECT(gmenu_item), "sub-menu", sub_menu);
+    }
+    return gmenu_item;
+}
 
 /** Add one extension item to the UI manager.  This function creates a
  *  per-callback data structure for easy access to the opaque Scheme
@@ -375,24 +412,41 @@ static void
 gnc_menu_additions_menu_setup_one (ExtensionInfo *ext_info,
                                    GncPluginMenuAdditionsPerWindow *per_window)
 {
-    GncMainWindowActionData *cb_data;
+    GMenuItem *item_path, *item_with_full_path;
+    gchar *full_path = NULL;
+    GMenuItem *gmenu_item = NULL;
 
-    DEBUG( "Adding %s/%s [%s] as [%s]", ext_info->path, ext_info->ae.label,
-           ext_info->ae.name, ext_info->typeStr );
+    DEBUG("Adding %s/%s [%s] as [%s]", ext_info->path, ext_info->action_label,
+           ext_info->action_name, ext_info->typeStr );
 
-    cb_data = g_new0 (GncMainWindowActionData, 1);
-    cb_data->window = per_window->window;
-    cb_data->data = ext_info->extension;
+    g_hash_table_insert (per_window->item_hash, g_strdup (ext_info->action_name), ext_info->extension);
 
-    if (ext_info->type == GTK_UI_MANAGER_MENUITEM)
-        ext_info->ae.callback = (GCallback)gnc_plugin_menu_additions_action_cb;
+    if (g_str_has_suffix (ext_info->path, _("_Custom")))
+        return;
 
-    gtk_action_group_add_actions_full(per_window->group, &ext_info->ae, 1,
-                                      cb_data, g_free);
-    gtk_ui_manager_add_ui(per_window->ui_manager, per_window->merge_id,
-                          ext_info->path, ext_info->ae.label, ext_info->ae.name,
-                          ext_info->type, FALSE);
-    gtk_ui_manager_ensure_update(per_window->ui_manager);
+    full_path = g_strconcat (ext_info->path, "/", ext_info->action_label, NULL);
+
+    item_path = g_hash_table_lookup (per_window->build_menu_hash, ext_info->path);
+    item_with_full_path = g_hash_table_lookup (per_window->build_menu_hash, full_path);
+
+    if (!item_path && !item_with_full_path)
+    {
+        gmenu_item = setup_gmenu_item_with_tooltip (ext_info);
+
+        g_menu_append_item (G_MENU(per_window->report_menu), gmenu_item);
+    }
+
+    if (item_path && !item_with_full_path)
+    {
+        GMenuModel *sub_menu = G_MENU_MODEL(g_object_get_data (G_OBJECT(item_path), "sub-menu"));
+
+        gmenu_item = setup_gmenu_item_with_tooltip (ext_info);
+
+        g_menu_append_item (G_MENU(sub_menu), gmenu_item);
+    }
+    g_hash_table_insert (per_window->build_menu_hash, g_strdup (full_path), gmenu_item);
+
+    g_free (full_path);
 }
 
 
@@ -410,42 +464,57 @@ gnc_menu_additions_menu_setup_one (ExtensionInfo *ext_info,
  */
 static void
 gnc_plugin_menu_additions_add_to_window (GncPlugin *plugin,
-        GncMainWindow *window,
-        GQuark type)
+                                         GncMainWindow *window,
+                                         GQuark type)
 {
     GncPluginMenuAdditionsPerWindow per_window;
     static GOnce accel_table_init = G_ONCE_INIT;
     static GHashTable *table;
     GSList *menu_list;
+    GMenuModel *menubar_model = gnc_main_window_get_menu_model (window);
+    GncMenuModelSearch *gsm = g_new0 (GncMenuModelSearch, 1);
 
     ENTER(" ");
 
-    per_window.window = window;
-    per_window.ui_manager = window->ui_merge;
-    per_window.group = gtk_action_group_new ("MenuAdditions" );
-    gtk_action_group_set_translation_domain (per_window.group, PROJECT_NAME);
-    per_window.merge_id = gtk_ui_manager_new_merge_id(window->ui_merge);
-    gtk_ui_manager_insert_action_group(window->ui_merge, per_window.group, 0);
+    GncPluginMenuAdditions *menu_plugin = GNC_PLUGIN_MENU_ADDITIONS (plugin);
+    if (!menu_plugin->item_hash)
+        menu_plugin->item_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
-    menu_list = g_slist_sort(gnc_extensions_get_menu_list(),
-                             (GCompareFunc)gnc_menu_additions_sort);
+    per_window.item_hash = menu_plugin->item_hash;
+    per_window.build_menu_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+    per_window.report_menu = g_menu_new ();
+
+    menu_list = g_slist_sort (gnc_extensions_get_menu_list(),
+                              (GCompareFunc)gnc_menu_additions_sort);
 
     /* Assign accelerators */
-    table = g_once(&accel_table_init, gnc_menu_additions_init_accel_table, NULL);
-    g_slist_foreach(menu_list,
+    table = g_once (&accel_table_init, gnc_menu_additions_init_accel_table, NULL);
+    g_slist_foreach (menu_list,
                     (GFunc)gnc_menu_additions_do_preassigned_accel, table);
-    g_slist_foreach(menu_list, (GFunc)gnc_menu_additions_assign_accel, table);
+    g_slist_foreach (menu_list, (GFunc)gnc_menu_additions_assign_accel, table);
 
-    /* Add to window. */
-    g_slist_foreach(menu_list, (GFunc)gnc_menu_additions_menu_setup_one,
-                    &per_window);
+    /* Create the menu. */
+    g_slist_foreach (menu_list, (GFunc)gnc_menu_additions_menu_setup_one,
+                     &per_window);
 
-    /* Tell the window code about the actions that were just added
-     * behind its back (so to speak) */
-    gnc_main_window_manual_merge_actions (window, PLUGIN_ACTIONS_NAME,
-                                          per_window.group, per_window.merge_id);
+    // add the report menu to the window
+    gsm->search_action_label = NULL;
+    gsm->search_action_name = "ReportsPlaceholder0";
+    gsm->search_action_target = NULL;
+
+    if (gnc_menubar_model_find_item (menubar_model, gsm))
+    {
+        g_menu_insert_section (G_MENU(gsm->model), gsm->index, NULL, G_MENU_MODEL(per_window.report_menu));
+    }
+    else
+        PERR("Could not find 'ReportsAction' in menu model");
+
+    g_hash_table_destroy (per_window.build_menu_hash);
+
+    g_slist_free (menu_list);
+
+    g_free (gsm);
 
-    g_slist_free(menu_list);
     LEAVE(" ");
 }
 
@@ -463,23 +532,19 @@ gnc_plugin_menu_additions_add_to_window (GncPlugin *plugin,
  */
 static void
 gnc_plugin_menu_additions_remove_from_window (GncPlugin *plugin,
-        GncMainWindow *window,
-        GQuark type)
+                                              GncMainWindow *window,
+                                              GQuark type)
 {
-    GtkActionGroup *group;
+    GSimpleActionGroup *simple_action_group;
 
     ENTER(" ");
 
     /* Have to remove our actions manually. Its only automatic if the
      * actions name is installed into the plugin class. */
-    group = gnc_main_window_get_action_group(window, PLUGIN_ACTIONS_NAME);
+    simple_action_group = gnc_main_window_get_action_group (window, PLUGIN_ACTIONS_NAME);
 
-    if (group && !window->just_plugin_prefs)
-        gtk_ui_manager_remove_action_group(window->ui_merge, group);
-
-    /* Note: This code does not clean up the per-callback data structures
-     * that are created by the gnc_menu_additions_menu_setup_one()
-     * function. Its not much memory and shouldn't be a problem. */
+    if (simple_action_group && !window->just_plugin_prefs)
+        gtk_widget_insert_action_group (GTK_WIDGET(window), PLUGIN_ACTIONS_NAME, NULL);
 
     LEAVE(" ");
 }
