@@ -31,7 +31,6 @@
 
 #include "gnucash-core-app.hpp"
 
-extern "C" {
 #include <glib/gi18n.h>
 #include <binreloc.h>
 #include <gnc-engine.h>
@@ -42,17 +41,16 @@ extern "C" {
 #include <gnc-path.h>
 #include <gnc-prefs.h>
 #include <gnc-gsettings.h>
-#include <gnc-report.h>
 #include <gnc-splash.h>
 #include <gnc-version.h>
 #include "gnucash-locale-platform.h"
-}
 
 #include <boost/algorithm/string.hpp>
 #include <boost/locale.hpp>
 #include <iostream>
 #include <string>
 #include <vector>
+#include <gnc-report.h>
 
 namespace bl = boost::locale;
 
@@ -65,9 +63,9 @@ static QofLogModule log_module = GNC_MOD_GUI;
 
 /* GNC_VCS is defined whenever we're building from an svn/svk/git/bzr tree */
 #ifdef GNC_VCS
-static int is_development_version = TRUE;
+constexpr int is_development_version = TRUE;
 #else
-static int is_development_version = FALSE;
+constexpr int is_development_version = FALSE;
 #define GNC_VCS ""
 #endif
 
@@ -169,7 +167,7 @@ gnc_log_init (const std::vector <std::string> log_flags,
     }
 }
 
-Gnucash::CoreApp::CoreApp ()
+Gnucash::CoreApp::CoreApp (const char* app_name) : m_app_name {app_name}
 {
     #ifdef ENABLE_BINRELOC
     {
@@ -212,14 +210,6 @@ Gnucash::CoreApp::CoreApp ()
     std::cerr.imbue (gnc_get_boost_locale());
     std::cout.imbue (gnc_get_boost_locale());
     g_free(localedir);
-}
-
-Gnucash::CoreApp::CoreApp (const char* app_name)
-{
-
-    CoreApp();
-
-    m_app_name = std::string(app_name);
 
     // Now that gettext is properly initialized, set our help tagline.
     m_tagline = _("- GnuCash, accounting for personal and small business finance");
@@ -245,24 +235,21 @@ Gnucash::CoreApp::parse_command_line (int argc, char **argv)
     catch (std::exception &e)
     {
         std::cerr << e.what() << "\n\n";
-        std::cerr << *m_opt_desc_display.get() << "\n";
+        std::cerr << *m_opt_desc_display.get() << std::endl;
 
         exit(1);
     }
 
     if (m_show_paths)
     {
-        auto paths { gnc_list_all_paths ()};
         std::cout << _("GnuCash Paths") << '\n';
-        for (auto n = paths; n; n = n->next)
+        for (const auto& ep : gnc_list_all_paths ())
         {
-            auto it = static_cast<EnvPaths*>(n->data);
-            std::cout << it->env_name << ": " << it->env_path;
-            if (it->modifiable)
+            std::cout << ep.env_name << ": " << ep.env_path;
+            if (ep.modifiable)
                 std::cout << ' ' << _("(user modifiable)");
             std::cout << '\n';
         }
-        g_list_free_full (paths, g_free);
         exit (0);
     }
 
@@ -282,7 +269,7 @@ Gnucash::CoreApp::parse_command_line (int argc, char **argv)
 
     if (m_show_help)
     {
-        std::cout << *m_opt_desc_display.get() << "\n";
+        std::cout << *m_opt_desc_display.get() << std::endl;
         exit(0);
     }
 
