@@ -36,6 +36,12 @@
 #include "Transaction.h"
 #include "import-backend.h"
 
+#include <stdbool.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct _main_matcher_info GNCImportMainMatcher;
 
 typedef void (*GNCTransactionProcessedCB) (GNCImportTransInfo *trans_info,
@@ -68,9 +74,9 @@ typedef void (*GNCTransactionProcessedCB) (GNCImportTransInfo *trans_info,
 */
 GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
                                               const gchar* heading,
-                                              gboolean all_from_same_account,
+                                              bool all_from_same_account,
                                               gint match_date_hardlimit,
-                                              gboolean show_all);
+                                              bool show_all);
 
 
 
@@ -105,7 +111,7 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
 GNCImportMainMatcher * gnc_gen_trans_assist_new (GtkWidget *parent,
                                                  GtkWidget *assistant_page,
                                                  const gchar* heading,
-                                                 gboolean all_from_same_account,
+                                                 bool all_from_same_account,
                                                  gint match_date_hardlimit);
 
 
@@ -155,6 +161,25 @@ void gnc_gen_trans_list_delete (GNCImportMainMatcher *info);
 void gnc_gen_trans_list_add_trans (GNCImportMainMatcher *gui, Transaction *trans);
 
 
+/** Add a newly imported Transaction to the Transaction Importer.
+ *  The Importer takes over ownership of the passed transaction.
+ *
+ * @param gui The Transaction Importer to use.
+ *
+ * @param trans The Transaction to add.  The must contain at least one
+ * split, and this split must have been associated with an account
+ * Only the first split will be used for matching.  The transaction
+ * must NOT be committed. The Importer takes over ownership of the
+ * passed transaction.
+ *
+ * @param lsplit Struct with additional parameters that may be used to
+ * generate the final split.
+ */
+void gnc_gen_trans_list_add_trans_with_split_data (GNCImportMainMatcher *gui,
+                                                   Transaction *trans,
+                                                   GNCImportLastSplitInfo *lsplit);
+
+
 /** Add a newly imported Transaction to the Transaction Importer and provide an
  * external reference id for it.
  * The Importer takes over ownership of the passed transaction.
@@ -180,7 +205,7 @@ void gnc_gen_trans_list_add_trans_with_ref_id (GNCImportMainMatcher *gui,
  * @param info A pointer to the GNCImportMainMatcher structure.
  * @return The boolean return value of the dialog run.
 */
-gboolean gnc_gen_trans_list_run (GNCImportMainMatcher *info);
+bool gnc_gen_trans_list_run (GNCImportMainMatcher *info);
 
 
 /** Returns the widget of this dialog.
@@ -200,7 +225,7 @@ gnc_gen_trans_list_append_text_widget (GNCImportMainMatcher *info);
  * @param info A pointer to the GNCImportMainMatcher structure.
  * @return A boolean indicating whether the transaction list is empty.
  */
-gboolean gnc_gen_trans_list_empty (GNCImportMainMatcher *info);
+bool gnc_gen_trans_list_empty (GNCImportMainMatcher *info);
 
 /** Shows widgets.
  * @param info A pointer to the GNCImportMainMatcher structure.
@@ -209,17 +234,21 @@ void gnc_gen_trans_list_show_all (GNCImportMainMatcher *info);
 
 /** Show and set the reconcile after close check button.
  * @param info A pointer to the GNCImportMainMatcher structure.
- * @param reconcile_after_close A gboolean that shows or hides the button.
- * @param active A gboolean to set or clear the check button.
+ * @param reconcile_after_close A bool that shows or hides the button.
+ * @param active A bool to set or clear the check button.
  */
 void gnc_gen_trans_list_show_reconcile_after_close_button (GNCImportMainMatcher *info,
-                                                           gboolean reconcile_after_close,
-                                                           gboolean active);
+                                                           bool reconcile_after_close,
+                                                           bool active);
 /** Returns the reconcile after close check button.
  * @param info A pointer to the GNCImportMainMatcher structure.
  * @return The check button.
  */
 GtkWidget* gnc_gen_trans_list_get_reconcile_after_close_button (GNCImportMainMatcher *info);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 /**@}*/
