@@ -76,12 +76,6 @@ enum matcher_cols
 /* Needs to be commented in again if any DEBUG() macro is used here. */
 /*static short module = MOD_IMPORT;*/
 
-/********************************************************************\
- *   Constants, should idealy be defined a user preference dialog    *
-\********************************************************************/
-
-static const int SHOW_NUMERIC_SCORE = FALSE;
-
 /********************************************************************\
  *               Structures passed between the functions             *
 \********************************************************************/
@@ -468,6 +462,10 @@ init_match_picker_gui(GtkWidget *parent, GNCImportMatchPicker * matcher)
     matcher->match_view = (GtkTreeView *)GTK_WIDGET(gtk_builder_get_object (builder, "matched_view"));
     matcher->reconciled_chk = (GtkCheckButton *)GTK_WIDGET(gtk_builder_get_object(builder, "hide_reconciled_check1"));
 
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(matcher->transaction_matcher), "gnc-id-import-matcher-picker");
+    gnc_widget_style_context_add_class (GTK_WIDGET(matcher->transaction_matcher), "gnc-class-imports");
+
     gtk_window_set_transient_for (GTK_WINDOW (matcher->transaction_matcher), GTK_WINDOW(parent));
 
     gnc_prefs_bind (GNC_PREFS_GROUP, GNC_PREF_DISPLAY_RECONCILED,
