@@ -61,10 +61,13 @@ enum
 #define MIN_BUTT_WIDTH 20 // minimum size for a button excluding border
 
 static QofLogModule log_module = G_LOG_DOMAIN;
-static GtkBoxClass *gnc_item_edit_parent_class;
 
-static GtkToggleButtonClass *gnc_item_edit_tb_parent_class;
 static void gnc_item_edit_destroying (GtkWidget *this, gpointer data);
+
+G_DEFINE_TYPE (GncItemEdit, gnc_item_edit, GTK_TYPE_BOX)
+
+G_DEFINE_TYPE (GncItemEditTb, gnc_item_edit_tb, GTK_TYPE_TOGGLE_BUTTON)
+
 static void
 gnc_item_edit_tb_init (GncItemEditTb *item_edit_tb)
 {
@@ -151,8 +154,6 @@ gnc_item_edit_tb_class_init (GncItemEditTbClass *gnc_item_edit_tb_class)
 
     gtk_widget_class_set_css_name (GTK_WIDGET_CLASS(gnc_item_edit_tb_class), "button");
 
-    gnc_item_edit_tb_parent_class = g_type_class_peek_parent (gnc_item_edit_tb_class);
-
     object_class = G_OBJECT_CLASS(gnc_item_edit_tb_class);
     widget_class = GTK_WIDGET_CLASS(gnc_item_edit_tb_class);
 
@@ -172,34 +173,6 @@ gnc_item_edit_tb_class_init (GncItemEditTbClass *gnc_item_edit_tb_class)
     widget_class->get_preferred_height = gnc_item_edit_tb_get_preferred_height;
 }
 
-GType
-gnc_item_edit_tb_get_type (void)
-{
-    static GType gnc_item_edit_tb_type = 0;
-
-    if (!gnc_item_edit_tb_type)
-    {
-        static const GTypeInfo gnc_item_edit_tb_info =
-        {
-            sizeof (GncItemEditTbClass),
-            NULL,
-            NULL,
-            (GClassInitFunc)gnc_item_edit_tb_class_init,
-            NULL,
-            NULL,
-            sizeof (GncItemEditTb),
-            0, /* n_preallocs */
-            (GInstanceInitFunc)gnc_item_edit_tb_init,
-            NULL,
-        };
-        gnc_item_edit_tb_type =
-            g_type_register_static (GTK_TYPE_TOGGLE_BUTTON,
-                                    "GncItemEditTb",
-                                    &gnc_item_edit_tb_info, 0);
-    }
-    return gnc_item_edit_tb_type;
-}
-
 GtkWidget *
 gnc_item_edit_tb_new (GnucashSheet *sheet)
 {
@@ -306,6 +279,9 @@ gnc_item_edit_focus_out (GncItemEdit *item_edit)
     g_return_if_fail (item_edit != NULL);
     g_return_if_fail (GNC_IS_ITEM_EDIT(item_edit));
 
+    if (item_edit->show_popup)
+        return; // Prevent recursion
+
     ev.type = GDK_FOCUS_CHANGE;
     ev.window = gtk_widget_get_window (GTK_WIDGET(item_edit->sheet));
     ev.in = FALSE;
@@ -561,7 +537,6 @@ draw_background_cb (GtkWidget *widget, cairo_t *cr, gpointer user_data)
 static void
 preedit_changed_cb (GtkEntry* entry, gchar *preedit, GncItemEdit* item_edit)
 {
-    int pos, bound;
     item_edit->preedit_length = g_utf8_strlen (preedit, -1); // Note codepoints not bytes
     DEBUG("%s %lu", preedit, item_edit->preedit_length);
 }
@@ -773,8 +748,6 @@ gnc_item_edit_class_init (GncItemEditClass *gnc_item_edit_class)
 
     gtk_widget_class_set_css_name (GTK_WIDGET_CLASS(gnc_item_edit_class), "gnc-id-cursor");
 
-    gnc_item_edit_parent_class = g_type_class_peek_parent (gnc_item_edit_class);
-
     object_class = G_OBJECT_CLASS(gnc_item_edit_class);
     widget_class = GTK_WIDGET_CLASS(gnc_item_edit_class);
 
@@ -794,39 +767,6 @@ gnc_item_edit_class_init (GncItemEditClass *gnc_item_edit_class)
     widget_class->get_preferred_height = gnc_item_edit_get_preferred_height;
 }
 
-/* FIXME: This way of initializing GObjects is obsolete. We should be
- * using G_DECLARE_FINAL_TYPE instead of rolling _get_type by hand.
- */
-GType
-gnc_item_edit_get_type (void)
-{
-    static GType gnc_item_edit_type = 0;
-
-    if (!gnc_item_edit_type)
-    {
-        static const GTypeInfo gnc_item_edit_info =
-        {
-            sizeof (GncItemEditClass),
-            NULL,
-            NULL,
-            (GClassInitFunc) gnc_item_edit_class_init,
-            NULL,
-            NULL,
-            sizeof (GncItemEdit),
-            0, /* n_preallocs */
-            (GInstanceInitFunc) gnc_item_edit_init,
-            NULL,
-        };
-
-        gnc_item_edit_type =
-            g_type_register_static (GTK_TYPE_BOX,
-                                    "GncItemEdit",
-                                    &gnc_item_edit_info, 0);
-    }
-
-    return gnc_item_edit_type;
-}
-
 gint
 gnc_item_edit_get_margin (GncItemEdit *item_edit, Sides side)
 {
@@ -1032,7 +972,7 @@ gnc_item_edit_show_popup (GncItemEdit *item_edit)
     gint popup_x, popup_y;
     gint popup_w = -1, popup_h = -1;
     gint popup_max_width, popup_max_height;
-    gint view_width, view_height;
+    gint view_height;
     gint down_height, up_height;
     gint sheet_width;
 
@@ -1089,6 +1029,12 @@ gnc_item_edit_show_popup (GncItemEdit *item_edit)
     // Lets check popup height is the true height
     item_edit->popup_returned_height = popup_h;
 
+    gtk_widget_get_allocation (GTK_WIDGET(item_edit), &alloc);
+
+    // the calendar will be 0
+    if ((popup_w != 0) && (popup_w < alloc.width))
+        popup_w = alloc.width;
+
     if (popup_h == popup_max_height)
         gtk_widget_set_size_request (item_edit->popup_item, popup_w - 1, popup_h);
     else
