@@ -38,10 +38,9 @@
   (gnc:options->sxml uuid options "test-balsheet-pnl" test-title))
 
 (define (set-option! options section name value)
-  (let ((option (gnc:lookup-option options section name)))
-    (if option
-        (gnc:option-set-value option value)
-        (test-assert (format #f "wrong-option ~a ~a" section name) #f))))
+  (if (gnc-lookup-option (gnc:optiondb options) section name)
+        (gnc-set-option (gnc:optiondb options) section name value)
+        (test-assert (format #f "wrong-option ~a ~a" section name) #f)))
 
 (define (mnemonic->commodity sym)
   (gnc-commodity-table-lookup
