@@ -329,7 +329,10 @@ void
 GncQuotesImpl::report (const char* source, const StrVec& commodities,
                        bool verbose)
 {
-    bool is_currency{source && strcmp(source, "currency") == 0};
+    if (!source)
+        throw (GncQuoteException(bl::translate("GncQuotes::Report called with no source.")));
+
+    bool is_currency{strcmp(source, "currency") == 0};
     m_failures.clear();
     if (commodities.empty())
     {
@@ -569,7 +572,7 @@ parse_quote_json(PriceParams& p, const bpt::ptree& comm_pt)
     PINFO("     Time: %s", (p.time ? p.time->c_str() : "missing"));
     PINFO(" Currency: %s", (p.currency ? p.currency->c_str() : "missing"));
     PINFO("    Price: %s", (p.price ? p.price->c_str() : "missing"));
-    PINFO(" Inverted: %s\n", (inverted ? "yes" : "no"));
+    PINFO(" Inverted: %s\n", (p.inverted ? "yes" : "no"));
 }
 
 static time64
