@@ -1935,7 +1935,7 @@ xaccParseAmountInternal (const char * in_str, gboolean monetary,
         {
             *out = '\0';
 
-            if (*out_str && sscanf(out_str, QOF_SCANF_LLD, &numer) < 1)
+            if (*out_str && sscanf(out_str, "%lld", &numer) < 1)
                 next_state = NO_NUM_ST;
             else if (next_state == FRAC_ST)
             {
@@ -1977,7 +1977,7 @@ xaccParseAmountInternal (const char * in_str, gboolean monetary,
         }
 
         long long int fraction;
-        if (sscanf (out_str, QOF_SCANF_LLD, &fraction) < 1)
+        if (sscanf (out_str, "%lld", &fraction) < 1)
         {
             g_free(out_str);
             return FALSE;
