@@ -28,8 +28,6 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-extern "C"
-{
 #include "config.h"
 
 #include <platform.h>
@@ -60,8 +58,6 @@ extern "C"
 #include "splint-defs.h"
 #endif
 
-}
-
 #include <boost/regex.hpp>
 #include <string>
 #include <iomanip>
@@ -182,7 +178,7 @@ UriStrings::quote_dbname(DbType t) const noexcept
 static void
 set_options(dbi_conn conn, const PairVec& options)
 {
-    for (auto option : options)
+    for (const auto& option : options)
     {
         auto opt = option.first.c_str();
         auto val = option.second.c_str();
@@ -209,7 +205,6 @@ GncDbiBackend<Type>::set_standard_connection_options (dbi_conn conn,
                                                 const UriStrings& uri)
 
 {
-    gint result;
     PairVec options;
     options.push_back(std::make_pair("host", uri.m_host));
     options.push_back(std::make_pair("dbname", uri.m_dbname));
@@ -224,7 +219,7 @@ GncDbiBackend<Type>::set_standard_connection_options (dbi_conn conn,
         {
             const char *msg = nullptr;
             auto err = dbi_conn_error(conn, &msg);
-            PERR("Error setting port option to %d: %s", uri.m_portnum, msg);
+            PERR("Error (%d) setting port option to %d: %s", err, uri.m_portnum, msg);
             throw std::runtime_error(msg);
         }
     }
@@ -642,7 +637,6 @@ template <DbType Type> void
 GncDbiBackend<Type>::session_begin (QofSession* session, const char* new_uri,
                                     SessionOpenMode mode)
 {
-    GncDbiTestResult dbi_test_result = GNC_DBI_PASS;
     PairVec options;
 
     g_return_if_fail (session != nullptr);
