@@ -29,14 +29,11 @@
  */
 #include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 
 #include "gnc-engine.h"
 
 #include "gncAddress.h"
-}
 #include <cstdlib>
 #include <cstring>
 #include <sstream>
@@ -80,9 +77,6 @@ GncSqlColumnTableEntryImpl<CT_ADDRESS>::load (const GncSqlBackend* sql_be,
                                               QofIdTypeConst obj_name,
                                               gpointer pObject) const noexcept
 {
-    const gchar* s;
-
-
     g_return_if_fail (sql_be != NULL);
     g_return_if_fail (pObject != NULL);
 
