@@ -649,7 +649,7 @@ _retrieve_guid_ (gpointer pObject,  gpointer pValue)
     g_return_if_fail (pObject != NULL);
     g_return_if_fail (pValue != NULL);
 
-    memcpy (pGuid, guid, sizeof (GncGUID));
+    *pGuid = *guid;
 }
 
 // Table to retrieve just the guid
