@@ -23,8 +23,6 @@
 \********************************************************************/
 #include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
@@ -33,7 +31,6 @@ extern "C"
 #include "gncOrderP.h"
 #include "gncInvoiceP.h"
 #include "gncTaxTableP.h"
-}
 
 #include "gnc-xml-helper.h"
 #include "sixtp.h"
@@ -253,11 +250,7 @@ static inline gboolean
 set_numeric (xmlNodePtr node, GncEntry* entry,
              void (*func) (GncEntry* entry, gnc_numeric num))
 {
-    gnc_numeric* num = dom_tree_to_gnc_numeric (node);
-    g_return_val_if_fail (num, FALSE);
-
-    func (entry, *num);
-    g_free (num);
+    func (entry, dom_tree_to_gnc_numeric (node));
     return TRUE;
 }
 
