@@ -25,8 +25,6 @@
  *                                                                  *
  *******************************************************************/
 #include <guid.hpp>
-extern "C"
-{
 #include <config.h>
 
 #include <stdlib.h>
@@ -44,7 +42,6 @@ extern "C"
 #include <TransLog.h>
 #include <gnc-pricedb.h>
 #include <gnc-pricedb-p.h>
-}
 
 #include "io-gncxml.h"
 #include "sixtp.h"
@@ -764,8 +761,6 @@ kvp_frame_slot_end_handler (gpointer data_for_children,
                             gpointer* result, const gchar* tag)
 {
     KvpFrame* f = (KvpFrame*) parent_data;
-    GSList* lp;
-    gboolean first = TRUE;
     gchar* key = NULL;
     KvpValue* value = NULL;
     gboolean delete_value = FALSE;
@@ -2972,10 +2967,7 @@ price_parse_xml_sub_node (GNCPrice* p, xmlNodePtr sub_node, QofBook* book)
     }
     else if (g_strcmp0 ("price:value", (char*)sub_node->name) == 0)
     {
-        gnc_numeric* value = dom_tree_to_gnc_numeric (sub_node);
-        if (!value) return FALSE;
-        gnc_price_set_value (p, *value);
-        g_free (value);
+        gnc_price_set_value (p, dom_tree_to_gnc_numeric (sub_node));
     }
     gnc_price_commit_edit (p);
     return TRUE;
