@@ -21,8 +21,6 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-extern "C"
-{
 #include <config.h>
 
 #include <platform.h>
@@ -65,7 +63,6 @@ extern "C"
 # define g_fopen fopen
 # define g_open _open
 #endif
-}
 
 #include "gnc-xml-backend.hpp"
 #include "sixtp-parsers.h"
@@ -76,20 +73,8 @@ extern "C"
 #include "io-gncxml-v2.h"
 #include "io-gncxml-gen.h"
 
-/* Do not treat -Wstrict-aliasing warnings as errors because of problems of the
- * G_LOCK* macros as declared by glib.  See
- * https://bugs.gnucash.org/show_bug.cgi?id=316221 for additional information.
- */
-#if (__GNUC__ >= 4 && __GNUC_MINOR__ >= 2)
-#    pragma GCC diagnostic warning "-Wstrict-aliasing"
-#endif
-
 static QofLogModule log_module = GNC_MOD_IO;
 
-/* map pointers, e.g. of type FILE*, to GThreads */
-static GHashTable* threads = NULL;
-G_LOCK_DEFINE_STATIC (threads);
-
 typedef struct
 {
     gint fd;
@@ -810,7 +795,7 @@ qof_session_load_from_xml_file_v2_full (
                                        generic_callback, gd, book);
             fclose (file);
             if (thread)
-                g_thread_join (thread) != nullptr;
+                g_thread_join (thread);
         }
     }
 
@@ -1617,14 +1602,19 @@ gnc_book_write_to_xml_file_v2 (QofBook* book, const char* filename,
         return false;
 
     /* Try to write as much as possible */
-    success = (gnc_book_write_to_xml_filehandle_v2 (book, file));
+    if (!gnc_book_write_to_xml_filehandle_v2 (book, file))
+        success = false;
 
     /* Close the output stream */
-    success = ! (fclose (file));
+    if (fclose (file))
+        success = false;
 
     /* Optionally wait for parallel compression threads */
     if (thread)
-        success =  g_thread_join (thread) != nullptr;
+    {
+        if (g_thread_join (thread) == nullptr)
+            success = false;
+    }
 
     return success;
 }
