@@ -66,7 +66,7 @@ typedef enum
 typedef struct AccountPrivate
 {
     /* The accountName is an arbitrary string assigned by the user.
-     * It is intended to a short, 5 to 30 character long string that
+     * It is intended to be a short, 5 to 30 character long string that
      * is displayed by the GUI as the account mnemonic.
      */
     const char *accountName;
@@ -121,6 +121,12 @@ typedef struct AccountPrivate
     gnc_numeric cleared_balance;
     gnc_numeric reconciled_balance;
 
+    gnc_numeric higher_balance_limit;
+    gboolean    higher_balance_cached;
+    gnc_numeric lower_balance_limit;
+    gboolean    lower_balance_cached;
+    TriState    include_sub_account_balances;
+ 
     gboolean balance_dirty;     /* balances in splits incorrect */
 
     GList *splits;              /* list of split pointers */
