@@ -33,23 +33,24 @@
 #include <boost/regex.hpp>
 #include <boost/locale/encoding_utf.hpp>
 
-extern "C"
-{
 #include <config.h>
+#include <stdexcept>
+#include <stdint.h>
+#include "gnc-int128.hpp"
 #include "qof.h"
-}
 
 #include "gnc-numeric.hpp"
 #include "gnc-rational.hpp"
 
 static QofLogModule log_module = "qof";
 
-static const uint8_t max_leg_digits{17};
+static const uint8_t max_leg_digits{18};
 static const int64_t pten[] = { 1, 10, 100, 1000, 10000, 100000, 1000000,
                                10000000, 100000000, 1000000000,
                                INT64_C(10000000000), INT64_C(100000000000),
                                INT64_C(1000000000000), INT64_C(10000000000000),
                                INT64_C(100000000000000),
+                               INT64_C(1000000000000000),
                                INT64_C(10000000000000000),
                                INT64_C(100000000000000000),
                                INT64_C(1000000000000000000)};
@@ -93,7 +94,7 @@ GncNumeric::GncNumeric(double d) : m_num(0), m_den(1)
     int64_t den;
     uint8_t den_digits;
     if (logval > 0.0)
-        den_digits = (max_leg_digits + 1) - static_cast<int>(floor(logval) + 1.0);
+        den_digits = (max_leg_digits + 1) - static_cast<int>(floor(logval));
     else
         den_digits = max_leg_digits;
     den = powten(den_digits);
@@ -114,14 +115,103 @@ GncNumeric::GncNumeric(double d) : m_num(0), m_den(1)
 }
 
 using boost::regex;
-using boost::smatch;
 using boost::regex_search;
-GncNumeric::GncNumeric(const std::string& str, bool autoround)
+using boost::smatch;
+
+
+static std::pair<int64_t, int64_t>
+reduce_number_pair(std::pair<GncInt128, GncInt128>num_pair,
+                   const std::string& num_str, bool autoround)
 {
+    auto [n, d] = num_pair;
+    if (!autoround && n.isBig()) {
+        std::ostringstream errmsg;
+        errmsg << "Decimal string " << num_str
+               << "can't be represented in a GncNumeric without rounding.";
+        throw std::overflow_error(errmsg.str());
+    }
+    while (n.isBig() && d > 0) {
+        n >>= 1;
+        d >>= 1;
+    }
+    if (n.isBig()) // Shouldn't happen, of course
+    {
+        std::ostringstream errmsg;
+        errmsg << "Decimal string " << num_str
+               << " can't be represented in a GncNumeric, even after reducing "
+            "denom to "
+               << d;
+        throw std::overflow_error(errmsg.str());
+    }
+    return std::make_pair(static_cast<int64_t>(n), static_cast<int64_t>(d));
+}
+
+static std::pair<GncInt128, int64_t>
+numeric_from_decimal_match(const std::string& integer, const std::string& decimal)
+{
+    auto neg = (!integer.empty() && integer[0] == '-');
+    GncInt128 high((neg && integer.length() > 1) || (!neg && !integer.empty())
+                   ? stoll(integer)
+                   : 0);
+    GncInt128 low{ decimal.empty() ? 0 : stoll(decimal)};
+    auto exp10 = decimal.length();
+    int64_t d = powten(exp10);
+    GncInt128 n = high * d + (neg ? -low : low);
+    while (exp10 > max_leg_digits) {
+        /* If the arg to powten is bigger than max_leg_digits
+           it returns 10**max_leg_digits so reduce exp10 by
+           that amount */
+        n = n / powten(exp10 - max_leg_digits);
+        exp10 -= max_leg_digits;
+    }
+    return std::make_pair(n, d);
+}
+
+static std::pair<GncInt128, GncInt128>
+numeric_from_scientific_match(smatch &m)
+{
+    int exp{m[4].matched ? stoi(m[4].str()) : 0};
+    auto neg_exp{exp < 0};
+    exp = neg_exp ? -exp : exp;
+    if (exp >= max_leg_digits)
+    {
+        std::ostringstream errmsg;
+        errmsg << "Exponent " << m[3].str() << " in match " << m[0].str()
+               << " exceeds range that GnuCash can parse.";
+        throw std::overflow_error(errmsg.str());
+    }
+
+    GncInt128 num, denom;
+    auto mult = powten(exp);
+
+    if (m[1].matched)
+    {
+        denom = neg_exp ? mult : 1;
+        num = neg_exp ? stoll(m[1].str()) : mult * stoll(m[1].str());
+    }
+    else
+    {
+        auto [d_num, d_denom] = numeric_from_decimal_match(m[2].str(), m[3].str());
+
+        if (neg_exp || d_denom > mult)
+        {
+            num = d_num;
+            denom = neg_exp ? d_denom * mult : d_denom / mult;
+        }
+        else
+        {
+            num = d_num * mult / d_denom;
+            denom = 1;
+        }
+    }
+    return std::make_pair(num, denom);
+}
+
+GncNumeric::GncNumeric(const std::string &str, bool autoround) {
     static const std::string numer_frag("(-?[0-9]*)");
     static const std::string denom_frag("([0-9]+)");
-    static const std::string hex_frag("(0x[a-f0-9]+)");
-    static const std::string slash( "[ \\t]*/[ \\t]*");
+    static const std::string hex_frag("(0[xX][A-Fa-f0-9]+)");
+    static const std::string slash("[ \\t]*/[ \\t]*");
     /* The llvm standard C++ library refused to recognize the - in the
      * numer_frag pattern with the default ECMAScript syntax so we use the
      * awk syntax.
@@ -133,33 +223,35 @@ GncNumeric::GncNumeric(const std::string& str, bool autoround)
     static const regex hex_over_num(hex_frag + slash + denom_frag);
     static const regex num_over_hex(numer_frag + slash + hex_frag);
     static const regex decimal(numer_frag + "[.,]" + denom_frag);
-    smatch m;
-/* The order of testing the regexes is from the more restrictve to the less
- * restrictive, as less-restrictive ones will match patterns that would also
- * match the more-restrictive and so invoke the wrong construction.
- */
+    static const regex scientific("(?:(-?[0-9]+[.,]?)|(-?[0-9]*)[.,]([0-9]+))[Ee](-?[0-9]+)");
+    static const regex has_hex_prefix(".*0[xX]$");
+    smatch m, x;
+    /* The order of testing the regexes is from the more restrictve to the less
+     * restrictive, as less-restrictive ones will match  patterns that would also
+     * match the more-restrictive and so invoke the wrong construction.
+     */
     if (str.empty())
-        throw std::invalid_argument("Can't construct a GncNumeric from an empty string.");
+        throw std::invalid_argument(
+            "Can't construct a GncNumeric from an empty string.");
     if (regex_search(str, m, hex_rational))
     {
         GncNumeric n(stoll(m[1].str(), nullptr, 16),
                      stoll(m[2].str(), nullptr, 16));
+
         m_num = n.num();
         m_den = n.denom();
         return;
     }
     if (regex_search(str, m, hex_over_num))
     {
-        GncNumeric n(stoll(m[1].str(), nullptr, 16),
-                     stoll(m[2].str()));
+        GncNumeric n(stoll(m[1].str(), nullptr, 16), stoll(m[2].str()));
         m_num = n.num();
         m_den = n.denom();
         return;
     }
     if (regex_search(str, m, num_over_hex))
     {
-        GncNumeric n(stoll(m[1].str()),
-                     stoll(m[2].str(), nullptr, 16));
+        GncNumeric n(stoll(m[1].str()), stoll(m[2].str(), nullptr, 16));
         m_num = n.num();
         m_den = n.denom();
         return;
@@ -171,42 +263,29 @@ GncNumeric::GncNumeric(const std::string& str, bool autoround)
         m_den = n.denom();
         return;
     }
+    if (regex_search(str, m, scientific) && ! regex_match(m.prefix().str(), x,  has_hex_prefix))
+    {
+        auto [num, denom] =
+            reduce_number_pair(numeric_from_scientific_match(m),
+                                   str, autoround);
+        m_num = num;
+        m_den = denom;
+        return;
+    }
     if (regex_search(str, m, decimal))
     {
-        auto neg = (m[1].length() && m[1].str()[0] == '-');
-        GncInt128 high((neg && m[1].length() > 1) || (!neg && m[1].length()) ?
-                       stoll(m[1].str()) : 0);
-        GncInt128 low(stoll(m[2].str()));
-        int64_t d = powten(m[2].str().length());
-        GncInt128 n = high * d + (neg ? -low : low);
-
-        if (!autoround && n.isBig())
-        {
-            std::ostringstream errmsg;
-            errmsg << "Decimal string " << m[1].str() << "." << m[2].str()
-                   << "can't be represented in a GncNumeric without rounding.";
-            throw std::overflow_error(errmsg.str());
-        }
-        while (n.isBig() && d > 0)
-        {
-            n >>= 1;
-            d >>= 1;
-        }
-        if (n.isBig()) //Shouldn't happen, of course
-        {
-            std::ostringstream errmsg;
-            errmsg << "Decimal string " << m[1].str() << "." << m[2].str()
-            << " can't be represented in a GncNumeric, even after reducing denom to " << d;
-            throw std::overflow_error(errmsg.str());
-        }
-        GncNumeric gncn(static_cast<int64_t>(n), d);
-        m_num = gncn.num();
-        m_den = gncn.denom();
+        std::string integer{m[1].matched ? m[1].str() : ""};
+        std::string decimal{m[2].matched ? m[2].str() : ""};
+        auto [num, denom] =
+            reduce_number_pair(numeric_from_decimal_match(integer, decimal),
+                               str, autoround);
+        m_num = num;
+        m_den = denom;
         return;
     }
     if (regex_search(str, m, hex))
     {
-        GncNumeric n(stoll(m[1].str(), nullptr, 16),INT64_C(1));
+        GncNumeric n(stoll(m[1].str(), nullptr, 16), INT64_C(1));
         m_num = n.num();
         m_den = n.denom();
         return;
@@ -658,8 +737,6 @@ gnc_numeric_positive_p(gnc_numeric a)
 int
 gnc_numeric_compare(gnc_numeric a, gnc_numeric b)
 {
-    gint64 aa, bb;
-
     if (gnc_numeric_check(a) || gnc_numeric_check(b))
     {
         return 0;
@@ -805,7 +882,6 @@ gnc_numeric
 gnc_numeric_sub(gnc_numeric a, gnc_numeric b,
                 gint64 denom, gint how)
 {
-    gnc_numeric nb;
     if (gnc_numeric_check(a) || gnc_numeric_check(b))
     {
         return gnc_numeric_error(GNC_ERROR_ARG);
@@ -1200,11 +1276,11 @@ gnc_numeric_error(GNCNumericErrorCode error_code)
 gchar *
 gnc_numeric_to_string(gnc_numeric n)
 {
-    gchar *result;
-    gint64 tmpnum = n.num;
-    gint64 tmpdenom = n.denom;
+    char *result;
+    int64_t tmpnum = n.num;
+    int64_t tmpdenom = n.denom;
 
-    result = g_strdup_printf("%" G_GINT64_FORMAT "/%" G_GINT64_FORMAT, tmpnum, tmpdenom);
+    result = g_strdup_printf("%" PRId64 "/%" PRId64, tmpnum, tmpdenom);
 
     return result;
 }
@@ -1214,13 +1290,14 @@ gnc_num_dbg_to_string(gnc_numeric n)
 {
     static char buff[1000];
     static char *p = buff;
-    gint64 tmpnum = n.num;
-    gint64 tmpdenom = n.denom;
+    static const uint64_t size = 50;
+    int64_t tmpnum = n.num;
+    int64_t tmpdenom = n.denom;
 
-    p += 100;
+    p += size;
     if (p - buff >= 1000) p = buff;
 
-    sprintf(p, "%" G_GINT64_FORMAT "/%" G_GINT64_FORMAT, tmpnum, tmpdenom);
+    snprintf(p, size, "%" PRId64 "/%" PRId64, tmpnum, tmpdenom);
 
     return p;
 }
@@ -1244,10 +1321,9 @@ string_to_gnc_numeric(const gchar* str, gnc_numeric *n)
 /* *******************************************************************
  *  GValue handling
  ********************************************************************/
-static gpointer
-gnc_numeric_boxed_copy_func( gpointer in_ptr )
+static gnc_numeric*
+gnc_numeric_boxed_copy_func( gnc_numeric *in_gnc_numeric )
 {
-    auto in_gnc_numeric = static_cast<gnc_numeric*>(in_ptr);
     if (!in_gnc_numeric)
         return nullptr;
 
@@ -1259,25 +1335,12 @@ gnc_numeric_boxed_copy_func( gpointer in_ptr )
 }
 
 static void
-gnc_numeric_boxed_free_func( gpointer in_gnc_numeric )
+gnc_numeric_boxed_free_func( gnc_numeric *in_gnc_numeric )
 {
     g_free( in_gnc_numeric );
 }
 
-GType
-gnc_numeric_get_type( void )
-{
-    static GType type = 0;
-
-    if ( type == 0 )
-    {
-        type = g_boxed_type_register_static( "gnc_numeric",
-                                             gnc_numeric_boxed_copy_func,
-                                             gnc_numeric_boxed_free_func );
-    }
-
-    return type;
-}
+G_DEFINE_BOXED_TYPE (gnc_numeric, gnc_numeric, gnc_numeric_boxed_copy_func, gnc_numeric_boxed_free_func)
 
 /* *******************************************************************
  *  gnc_numeric misc testing
