@@ -38,8 +38,6 @@
 #include <guid.hpp>
 #include <kvp-frame.hpp>
 
-extern "C"
-{
 #include <platform.h>
 #if PLATFORM(WINDOWS)
 #define __STDC_FORMAT_MACROS
@@ -69,11 +67,8 @@ extern "C"
 #include "test-engine-stuff.h"
 #include "test-stuff.h"
 #include "test-engine-strings.h"
-}
 #include <qofinstance-p.h>
 
-static gboolean glist_strings_only = FALSE;
-
 static GHashTable *exclude_kvp_types = NULL;
 static gint kvp_max_depth = 5;
 static gint kvp_frame_max_elements = 10;
@@ -127,20 +122,6 @@ set_max_kvp_frame_elements (gint max_kvp_frame_elements)
     kvp_frame_max_elements = MAX (max_kvp_frame_elements, 1);
 }
 
-static void
-kvp_exclude_type (KvpValue::Type kvp_type)
-{
-    gint *key;
-
-    if (!exclude_kvp_types)
-        exclude_kvp_types = g_hash_table_new (g_int_hash, g_int_equal);
-
-    key = g_new (gint, 1);
-    *key = kvp_type;
-
-    g_hash_table_insert (exclude_kvp_types, key, exclude_kvp_types);
-}
-
 static gboolean
 kvp_type_excluded (KvpValue::Type kvp_type)
 {
@@ -155,8 +136,6 @@ kvp_type_excluded (KvpValue::Type kvp_type)
     return FALSE;
 }
 
-static gboolean zero_nsec = FALSE;
-
 /* ========================================================== */
 
 static inline gboolean
@@ -225,12 +204,7 @@ get_random_time (void)
 GncGUID*
 get_random_guid(void)
 {
-    GncGUID *ret;
-
-    ret = g_new(GncGUID, 1);
-    guid_replace(ret);
-
-    return ret;
+    return guid_new();
 }
 
 /* ========================================================== */
@@ -1523,14 +1497,9 @@ get_random_guids(int max)
 }
 
 static void
-free_random_guids(GList *guids)
+free_guids(GList *guids)
 {
-    GList *node;
-
-    for (node = guids; node; node = node->next)
-        g_free (node->data);
-
-    g_list_free (guids);
+    g_list_free_full (guids, (GDestroyNotify)guid_free);
 }
 
 static QofQueryOp
@@ -1572,32 +1541,6 @@ get_random_queryop(void)
     return op;
 }
 
-static GSList *
-get_random_kvp_path (void)
-{
-    GSList *path;
-    gint len;
-
-    path = NULL;
-    len = get_random_int_in_range (1, kvp_max_depth);
-
-    while (len--)
-        path = g_slist_prepend (path, get_random_string_without ("\n\\"));
-
-    return g_slist_reverse (path);
-}
-
-static void
-free_random_kvp_path (GSList *path)
-{
-    GSList *node;
-
-    for (node = path; node; node = node->next)
-        g_free (node->data);
-
-    g_slist_free (path);
-}
-
 static QofIdType
 get_random_id_type (void)
 {
@@ -1705,11 +1648,9 @@ get_random_query(void)
     while (num_terms-- > 0)
     {
         gint pr_type;
-        KvpValue *value;
         time64 start;
         time64 end;
         GList *guids;
-        GSList *path;
         char *string;
         GncGUID *guid;
 
@@ -1725,7 +1666,7 @@ get_random_query(void)
              guids,
              compare_param<QofGuidMatch>(QOF_GUID_MATCH_NONE),
              get_random_queryop ());
-            free_random_guids (guids);
+            free_guids (guids);
             break;
 
         case 2: /*PR_ACTION */
@@ -1786,7 +1727,7 @@ get_random_query(void)
                                    guid,
                                    get_random_id_type (),
                                    get_random_queryop ());
-            g_free (guid);
+            guid_free (guid);
             break;
 
         case 8: /* PR_KVP */
@@ -2080,9 +2021,7 @@ make_trans_query (Transaction *trans, TestQueryTypes query_types)
         }
         xaccQueryAddAccountGUIDMatch (q, list, QOF_GUID_MATCH_ANY, QOF_QUERY_AND);
 
-        for (node = list; node; node = node->next)
-            g_free (node->data);
-        g_list_free (list);
+        free_guids (list);
     }
 
     if (query_types & GUID_QT)
