@@ -21,11 +21,6 @@
  * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  ********************************************************************/
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
 #include <config.h>
 #include "platform.h"
 #include <string.h>
@@ -35,9 +30,6 @@ extern "C"
 #include <unittest-support.h>
 /* Add specific headers for this class */
 
-#ifdef __cplusplus
-}
-#endif
 #include "../gnc-date.h"
 #include "../gnc-date-p.h"
 #include <locale.h>
@@ -48,7 +40,6 @@ extern "C"
 #endif
 
 static const gchar *suitename = "/qof/gnc-date";
-static const time64 secs_per_year = INT64_C(3600) * (INT64_C(24) * INT64_C(365) + 6);
 static const time64 max_secs = (INT64_C(3600) * (INT64_C(24) * INT64_C(365) + 6)) * (INT64_C(9999) - INT64_C(1970));
 
 typedef struct
@@ -70,18 +61,6 @@ typedef struct
     time64 t5;
 } FixtureA;
 
-static int
-offset_secs (TZOffset tz)
-{
-    return 3600 * tz.hours + 60 * tz.minutes;
-}
-
-static char*
-offset_string (TZOffset tz)
-{
-    return g_strdup_printf("%+02d%02d", tz.hours, tz.minutes);
-}
-
 static void setup (FixtureA *f, gconstpointer pData)
 {
     f->t0 = gnc_time(NULL);
@@ -365,7 +344,7 @@ test_gnc_time (void)
     time64 secs1, secs2;
     secs1 = gnc_time (&secs2);
     g_assert_cmpint (secs1, ==, secs2);
-    g_assert_cmpint (secs1, ==, time(0));
+    g_assert_cmpint (secs1, ==, gnc_time(NULL));
 }
 
 /* gnc_difftime and gnc_tm_free are just too simple to bother testing. */
@@ -1357,15 +1336,6 @@ test_gnc_date_timestamp (void)
 
     g_free (timestr);
 }
-/* gnc_iso8601_to_time64_gmt
-time64
-gnc_iso8601_to_time64_gmt(const char *str)// C: 6 in 3  Local: 0:0:0
-*/
-static gint
-get_nanoseconds (GDateTime *gdt)
-{
-    return g_date_time_get_microsecond (gdt) * 1000;
-}
 
 static void
 test_gnc_iso8601_to_time64_gmt (FixtureA *f, gconstpointer pData)
@@ -1391,18 +1361,6 @@ test_gnc_iso8601_to_time64_gmt (FixtureA *f, gconstpointer pData)
     t = gnc_iso8601_to_time64_gmt ("2061-01-25 23:21:19.0 -05:00");
     g_assert_cmpint (t, ==, f->t5);
 }
-/* gnc_time64_to_iso8601_buff
-char *
-gnc_time64_to_iso8601_buff (time64 t, char * buff)// C: 18 in 7  Local: 0:0:0
-*/
-static time64
-g_date_time_to_time64 (GDateTime *gdt)
-{
-    time64 t;
-    t = g_date_time_to_unix (gdt);
-    return t;
-}
-
 #define ISO8601_SIZE MAX_DATE_LENGTH + 4
 static gchar*
 format_timestring (time64 t, TZOffset tz)
@@ -1545,22 +1503,6 @@ test_gnc_dmy2time64_end (FixtureB *f, gconstpointer pData)
     g_log_set_default_handler (hdlr, 0);
 }
 
-static GDateTime*
-offset_adjust(GDateTime *gdt)
-{
-     Testfuncs *tf = gnc_date_load_funcs();
-     GTimeZone *zone = tf->timezone_new_local();
-     int interval = g_time_zone_find_interval(zone, G_TIME_TYPE_STANDARD,
-					      g_date_time_to_unix(gdt));
-     int offset = g_time_zone_get_offset(zone, interval) / 60;
-     int off_hr = (offset / 60) + (offset % 60 ? (offset < 0 ? -1 : 1) : 0);
-     int correction = off_hr < -10 ? -10 - off_hr : off_hr > 13 ? 13 - off_hr : 0;
-     GDateTime* new_gdt = g_date_time_add_hours(gdt, correction);
-     g_date_time_unref(gdt);
-     g_slice_free(Testfuncs, tf);
-     return new_gdt;
-}
-
 /*gnc_dmy2time64_neutral*/
 static void
 test_gnc_dmy2time64_neutral (FixtureB *f, gconstpointer pData)
