@@ -23,12 +23,9 @@
 #include <glib.h>
 #include <guid.hpp>
 
-extern "C"
-{
 #include <config.h>
 #include <unittest-support.h>
 #include "../qof.h"
-}
 #include "../qof-backend.hpp"
 #include "../kvp-frame.hpp"
 static const gchar *suitename = "/qof/qofinstance";
@@ -199,9 +196,6 @@ test_instance_new_destroy( void )
     /* test var */
     Time64 *time_priv;
     const char *msg1 = "qof_instance_get_collection: assertion 'QOF_IS_INSTANCE(ptr)' failed";
-    const char *msg2 = "qof_instance_get_editlevel: assertion 'QOF_IS_INSTANCE(ptr)' failed";
-    const char *msg3 = "qof_instance_get_destroying: assertion 'QOF_IS_INSTANCE(ptr)' failed";
-    const char *msg4 = "qof_instance_get_dirty_flag: assertion 'QOF_IS_INSTANCE(ptr)' failed";
     const char *log_domain = "qof";
     auto loglevel = static_cast<GLogLevelFlags>(G_LOG_LEVEL_CRITICAL | G_LOG_FLAG_FATAL);
     auto check = test_error_struct_new(log_domain, loglevel, msg1);
@@ -437,15 +431,6 @@ test_instance_display_name( Fixture *fixture, gconstpointer pData )
     qof_collection_destroy( col );
 }
 
-static void
-mock_backend_begin( QofBackend *be, QofInstance *inst )
-{
-    g_assert( be );
-    g_assert( inst );
-    g_assert_cmpstr( inst->e_type, == , "test type" );
-    is_called = TRUE;
-}
-
 static void
 test_instance_begin_edit( Fixture *fixture, gconstpointer pData )
 {
